@@ -18,6 +18,7 @@
 #include <ucommon/export.h>
 #include <sipwitch/process.h>
 #include <sipwitch/service.h>
+#include <sipwitch/modules.h>
 #include <ctype.h>
 #include <errno.h>
 #include <stdarg.h>
@@ -102,6 +103,20 @@ static void logfile(fsys_t &fs)
 	fsys::create(fs, buf, fsys::ACCESS_APPEND, 0660); 
 }
 
+FILE *process::callfile(void)
+{
+	char buf[128];
+	FILE *fp;
+
+	snprintf(buf, sizeof(buf), DEFAULT_VARPATH "/log/%s.calls", ident);
+	fp = fopen(buf, "a");
+	if(fp)
+		return fp;
+
+	snprintf(buf, sizeof(buf), "/tmp/%s-%s/calls", ident, process::identity());
+	return fopen(buf, "a");
+}
+
 FILE *process::statfile(void)
 {
 	char buf[128];
@@ -212,8 +227,8 @@ void process::errlog(errlevel_t loglevel, const char *fmt, ...)
 			else
 				fprintf(stderr, "sipw: %s\n", buf);
 		}
-		service::snmptrap(loglevel + 10, buf);
 		::syslog(level, "%s", buf);
+		modules::errlog(loglevel, buf);
 	}
 	
 	if(level == LOG_CRIT)
@@ -247,6 +262,18 @@ static void get_system_time(uuid_time_t *uuid_time)
     *uuid_time = time.QuadPart;
 }
 
+FILE *process::callfile(void)
+{
+	char buf[256];
+	unsigned len;
+
+	GetEnvironmentVariable("APPDATA", buf, 192);
+	len = strlen(buf);
+	snprintf(buf + len, sizeof(buf) - len, "\\%s\\service.calls", ident);
+	
+	return fopen(buf, "a");
+}
+
 FILE *process::statfile(void)
 {
 	char buf[256];
@@ -692,6 +719,54 @@ FILE *process::config(const char *uid)
 	return fopen(buf, "r");
 }
 
+void process::uuid(char *buffer, size_t size, unsigned short seq, unsigned callid)
+{
+	unsigned char uuid[16];
+	unsigned pos = 0, dest = 0;
+	unsigned hi, lo;
+	unsigned long time_low; 
+	unsigned short time_mid;
+	uuid_time_t time_now;
+
+	static const char hex[] = "0123456789abcdef";
+		
+	get_system_time(&time_now);
+	time_now = time_now / 1024;
+
+	time_low = (unsigned long)(time_now & 0xffffffff);
+	time_mid = (unsigned short)((time_now >> 32) & 0xffff);
+
+	uuid[0] = time_low >> 24;
+	uuid[1] = (time_low >> 16) & 0xff;
+	uuid[2] = (time_low >> 8) & 0xff;
+	uuid[3] = time_low > 0xff;
+	uuid[4] = (time_mid >> 8) & 0xff;
+	uuid[5] = time_mid & 0xff;
+	uuid[6] = rand() & 0x0f;
+	uuid[7] = rand();
+	uuid[8] = 0x3f & (seq >> 8);
+	uuid[9] = seq & 0xff;
+
+	srand(callid);
+
+	for(unsigned entry = 10; entry < 16; ++entry)
+		uuid[entry] = rand();
+
+	while(pos < sizeof(uuid) && dest < (size - 3)) {
+		if(pos == 4 || pos == 6 || pos == 8 || pos == 10) {
+			buffer[dest++] = '-';
+			if(dest >= (size - 3))
+				break;
+		}
+		hi = uuid[pos] >> 4;
+		lo = uuid[pos] & 0x0f;
+		buffer[dest++] = hex[hi];
+		buffer[dest++] = hex[lo];
+		++pos;
+	}
+	buffer[dest++] = 0;
+}	
+
 void process::uuid(char *buffer, size_t size, const char *node)
 {
 	unsigned char uuid[16];
