@@ -38,7 +38,7 @@ static bool activating(int argc, char **args)
 		addr = server::getContact(args[1]);
 	if(!addr)
 		return false;
-	if(NULL == (reg = registry::create(args[1]))) {
+	if(NULL == (reg = registry::allocate(args[1]))) {
 		delete addr;
 		return false;
 	}
@@ -1001,7 +1001,7 @@ void server::usage(void)
 		"  -memleak              Find where leaks are with valgrind\n"
 #endif
 	);
-	printf("Report bugs to dyfet@gnutelephony.org\n");
+	printf("Report bugs to sipwitch-devel@gnu.org\n");
 	exit(0);
 }
 
