@@ -48,7 +48,7 @@ using namespace UCOMMON_NAMESPACE;
 
 class thread;
 
-class __LOCAL registry : private service::callback, private mapped_reuse<MappedRegistry> 
+class __LOCAL registry : private service::callback, private mapped_array<MappedRegistry> 
 { 
 public: 
 	class __LOCAL mapped : public MappedRegistry
@@ -137,6 +137,7 @@ private:
 	void stop(service *cfg);
 	void snapshot(FILE *fp);
 
+	static void clear(mapped *rr);
 	static void expire(mapped *rr);
 	static mapped *find(const char *id);
 
@@ -181,7 +182,7 @@ public:
 	static mapped *contact(const char *uri);
 	static mapped *contact(struct sockaddr *addr, const char *uid);
 	static mapped *getExtension(const char *id);
-	static mapped *create(const char *id);
+	static mapped *allocate(const char *id);
 	static mapped *access(const char *id);
 	static mapped *invite(const char *id, stats::stat_t stat);
 	static mapped *dialing(const char *id);
@@ -244,6 +245,7 @@ private:
 		char sysident[MAX_IDENT_SIZE];	// ident of this session
 		char display[MAX_DISPLAY_SIZE];	// callerid reference field
 		char from[MAX_URI_SIZE + MAX_DISPLAY_SIZE];	// formatted from line for endpoint
+		char uuid[48];
 
 		char authid[MAX_USERID_SIZE];	// for authentication...
 		char secret[MAX_USERID_SIZE];
