@@ -225,6 +225,7 @@ static void registry(char **argv)
 			continue;
 		else if(buffer.type == MappedRegistry::TEMPORARY && !buffer.inuse)
 			continue;
+
 		if(!found++)
 			printf("%7s %-30s type %-30s  use expires address\n", "ext", "user", "profile");
 		ext[0] = 0;
@@ -378,7 +379,7 @@ static void usage(void)
         "  verbose <level>         Server verbose logging level\n"
 	);		
 
-	printf("Report bugs to dyfet@gnutelephony.org\n");
+	printf("Report bugs to sipwitch-devel@gnu.org\n");
 	exit(0);
 }
 
